import styled from "styled-components";
import Task, { ITask } from "./Task";
import { Droppable, DroppableStateSnapshot } from "react-beautiful-dnd";
import React from "react";

const Container = styled.div`
  margin: 8px;
  border: 1px solid lightgrey;
  border-radius: 2px;
  width: 400px;
  display: flex;
  flex-direction: column;
  justify-content: space-between;
`;

const Title = styled.h3`
  padding: 8px;
`;

const TaskList = styled.div`
  padding: 8px;
  transition: background-color 0.2s ease;
  background-color: ${(props: DroppableStateSnapshot) =>
    props.isDraggingOver ? "#4038dd" : "#4038ff"};
  flex-grow: 1;
  min-height: 100px;
`;

export interface IColumn {
  id: string;
  title: string;
  taskIds: string[];
}

class InnerList extends React.Component {
  shouldComponentUpdate(nextProps: { tasks: any }) {
    if (nextProps.tasks === this.props.tasks) {
      return false;
    }
    return true;
  }
  render() {
    return this.props.tasks.map((task: ITask, index: number) => (
      <Task key={task.id} task={task} index={index} />
    ));
  }
}

const Column = (props: {
  column: IColumn;
  tasks: ITask[];
  isDropDisabled: boolean;
}) => {
  return (
    <Container>
      <Title>{props.column.title}</Title>
      <Droppable
        droppableId={props.column.id}
        isDropDisabled={props.isDropDisabled}
      >
        {(provided, snapshot) => (
          <TaskList
            ref={provided.innerRef}
            isDraggingOver={snapshot.isDraggingOver}
            {...provided.droppableProps}
          >
            <InnerList tasks={props.tasks} />
            {provided.placeholder}
          </TaskList>
        )}
      </Droppable>
    </Container>
  );
};

export default Column;
