import {
  createStyles,
  Grid,
  makeStyles,
  Theme,
  Typography,
} from "@material-ui/core";
import styled from "styled-components";
import Column, { IColumn } from "./Column";
import { DragDropContext } from "react-beautiful-dnd";

import initialData from "./initiadData";
import { useState } from "react";

const Container = styled.div`
  display: flex;
  justify-content: center;
`;

const useStyles = makeStyles((theme: Theme) =>
  createStyles({
    root: {
      textAlign: "center",
      backgroundColor: "#000",
      color: "#fff",
    },
  })
);

const IssueTracker = () => {
  const classes = useStyles();

  const [data, setData] = useState(initialData);
  const [homeIndex, setHomeIndex] = useState(null as number | null);

  const onDragStart = (start: { source: { droppableId: string } }) => {
    const homeIndex = data.columnOrder.indexOf(start.source.droppableId);
    setHomeIndex(homeIndex);
  };

  const onDragEnd = (result: {
    destination: any;
    source: any;
    draggableId: any;
  }) => {
    setHomeIndex(null);

    const { destination, source, draggableId } = result;

    if (!destination) {
      return;
    }

    if (
      destination.droppableId === source.droppableId &&
      destination.index === source.index
    ) {
      return;
    }

    const home = data.columns[source.droppableId] as IColumn;
    const foreign = data.columns[destination.droppableId] as IColumn;

    if (home === foreign) {
      const newTaskIds = Array.from(home.taskIds);
      newTaskIds.splice(source.index, 1);
      newTaskIds.splice(destination.index, 0, draggableId);

      const newHome = {
        ...home,
        taskIds: newTaskIds,
      };

      setData((prevData) => {
        return {
          ...prevData,
          columns: {
            ...prevData.columns,
            [newHome.id]: newHome,
          },
        };
      });
      return;
    }

    // Moving from one list to another
    const homeTaskIds = Array.from(home.taskIds);
    homeTaskIds.splice(source.index, 1);
    const newStart = {
      ...home,
      taskIds: homeTaskIds,
    };

    const foreignTaskIds = Array.from(foreign.taskIds);
    foreignTaskIds.splice(destination.index, 0, draggableId);
    const newFinish = {
      ...foreign,
      taskIds: foreignTaskIds,
    };

    setData((prevData) => {
      return {
        ...prevData,
        columns: {
          ...prevData.columns,
          [newStart.id]: newStart,
          [newFinish.id]: newFinish,
        },
      };
    });
  };

  return (
    <Grid className={classes.root} item lg={12}>
      <Typography variant="h2" className="mb-3">
        Issues
      </Typography>
      <DragDropContext onDragStart={onDragStart} onDragEnd={onDragEnd}>
        <Container>
          {initialData.columnOrder.map((columnId: string, index: number) => {
            const column = data.columns[columnId] as IColumn;
            const tasks = column.taskIds.map(
              (taskId: string) => data.tasks[taskId]
            );
            const isDropDisabled = index < homeIndex;
            return (
              <Column
                key={column.id}
                column={column}
                tasks={tasks}
                isDropDisabled={isDropDisabled}
              />
            );
          })}
        </Container>
      </DragDropContext>
    </Grid>
  );
};

export default IssueTracker;
